/* -- $Id: FOConverter.java,v 1.7 2003/09/10 09:01:11 kshaikh Exp $ --
 Copyright (C) 2001 Auriga Logic <http://www.aurigalogic.com>
 Author: Khurshidali Shaikh <kshaikh@aurigalogic.com>

 ============================================================================
		    GNU GENERAL PUBLIC LICENSE Version 2, June 1991
 ============================================================================

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
package com.aurigalogic.aurigadoc.core;

import java.io.*;

/**
 * This class is used for converting AurigaDoc document to xsl-fo.
 *
 * @author <a href="mailto:kshaikh@aurigalogic.com">Khurshidali Shaikh</a>
 * @version $Revision: 1.7 $ $Date: 2003/09/10 09:01:11 $
 */

public class FOConverter extends BaseConverter {

	/**
	 * Main method which does the conversion.
	 * @throws Exception in case of an error.
	 */
	public void convert() throws Exception {
		logInfo("Converting to FO..");
		FileOutputStream fos = new FileOutputStream(outputFile);
		createFO(getXSLForKey(XSL, XML2FO), 
				new FileInputStream(inputFile), fos);
		fos.close();
	}

	/**
	 * Generates the fo document
	 * @param xslFile the xsl file
	 * @param in the xml stream
	 * @param out the fo output stream
	 * @throws Exception in case of an error.
	 */
	protected void createFO(String xslFile, InputStream in, OutputStream out) 
			throws Exception {
		String cssTreeFile = null;
		try {
			FOCSSHandler cssHandler = new FOCSSHandler(inputFile, outputFile);
			if (cssHandler.isCssPresent()) {
				cssTreeFile = cssHandler.getCssTreeFile();
				setTransformerParameter("css-file", cssTreeFile);
			}
			doTransform(in, out, xslFile, OUTPUT_XML);
		} catch (Exception e) {
			throw e;
		} finally {
			if (cssTreeFile != null) {
				try {
					(new File(cssTreeFile)).delete();
				} catch (Exception e2) {
					// do nothing
				}
			}
		}
	}



}
