/* -- $Id: MHTMLConverter.java,v 1.8 2003/07/11 16:41:32 kshaikh Exp $ --
 Copyright (C) 2001 Auriga Logic <http://www.aurigalogic.com>
 Author: Khurshidali Shaikh <kshaikh@aurigalogic.com>

 ============================================================================
		    GNU GENERAL PUBLIC LICENSE Version 2, June 1991
 ============================================================================

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/
package com.aurigalogic.aurigadoc.core;

import java.io.*;

/**
 * This class is used for converting AurigaDoc document to multiple html files.
 *
 * @author <a href="mailto:kshaikh@aurigalogic.com">Khurshidali Shaikh</a>
 * @version $Revision: 1.8 $ $Date: 2003/07/11 16:41:32 $
 */

public class MHTMLConverter extends BaseConverter {


	/**
	 * Main method which does the conversion.
	 * @throws Exception in case of an error
	 */
	public void convert() throws Exception {
		logInfo("Converting to MULTI-PAGE HTML..");
		convertToMHTML(outputFile);
	}

	/**
	 * Converts the inputFile to multiple html files in the dir
	 * specified by outputDir.
	 *
	 * @param outputDir the output directory
	 * @throws Exception in case of an error
	 */
	protected void convertToMHTML(String outputDir) throws Exception {
		if (!outputDir.endsWith("/")) {
			outputDir += "/";
		}

		logInfo("Generating multiple html files...");
		setTransformerParameter("abs-out-dir", getOutputDir(outputDir, true));
		setTransformerParameter("rel-out-dir", getOutputDir(outputDir, false));

		String outputFile = outputDir + "table_of_content.html";
		FileOutputStream fos = new FileOutputStream(outputFile);
		doTransform(new FileInputStream(inputFile), 
			fos, getXSLForKey(XSL, XML2MHTML), OUTPUT_HTML);
		fos.close();
	}

	/**
	 * Gets the dir for the given file name, if the path is a dir same is 
	 * returned else the dir of the file is returned.
	 */
	private String getOutputDir(String outputFile, boolean absolute) {
		File outFile = new File(outputFile);
		String outputDir = outputFile;
		File parentDir;
		if (!outFile.isDirectory()) {
			parentDir = outFile.getParentFile();
		} else {
			parentDir = outFile;
		}
		if (parentDir != null) {
			if (absolute) {
				outputDir = parentDir.getAbsolutePath();
			} else {
				outputDir = parentDir.getPath();
			}
		}
		if (!outputDir.endsWith(File.separator)) {
			outputDir += File.separator;
		}
		return outputDir;
	}


}
