<?xml version="1.0" encoding="UTF-8"?>
<!-- $Id: xml2toc.xsl,v 1.7 2003/10/16 15:24:34 kshaikh Exp $ -->
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">

<xsl:output method="xml" indent="yes"/>

<!-- B: COMMON VARIABLES -->
<!--
*************************************************************************
Here we declare the document scope variable 
*************************************************************************
-->
<xsl:variable name="dfi" select="/document/document-formatting-info"/>

<xsl:variable name="toc" select="/document/document-body/table-of-content"/>

<xsl:variable name="dmi" select="/document/document-meta-info"/>

<xsl:variable name="nbsp">
<xsl:text> </xsl:text>
</xsl:variable>

<!-- number format for numbering sections -->
<xsl:variable name="snf">
<xsl:choose>
<xsl:when test="$dfi/generate-section-numbers/@number-format">
<xsl:value-of select="$dfi/generate-section-numbers/@number-format"/>
</xsl:when>
<xsl:otherwise>1</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<xsl:variable name="generate-section-numbers">
<xsl:choose>
<xsl:when test="$dfi/generate-section-numbers  = 'no'">no</xsl:when>
<xsl:otherwise>yes</xsl:otherwise>
</xsl:choose>
</xsl:variable>

<!-- E: COMMON VARIABLES -->

<!-- document -->
<xsl:template match="document">
<toc version="1.0" categoryclosedimage="closedFolderIcon" categoryopenimage="openFolderIcon" topicimage="topicIcon">
	<xsl:apply-templates select="document-body/table-of-content"/>
</toc>
</xsl:template>

<xsl:template match="table-of-content">
	<tocitem text="{$dmi/title}" image="toplevelfolder" target="table_of_content">
		<xsl:apply-templates select="link"/>
	</tocitem>
</xsl:template>

<xsl:template match="link">
<xsl:variable name="section-no">
<xsl:choose>
<xsl:when test="$generate-section-numbers = 'yes'">
<xsl:number level="multiple" format="{$snf}"/>. </xsl:when>
<xsl:otherwise/>
</xsl:choose>
</xsl:variable>
<tocitem>
<xsl:variable name="text">
<xsl:call-template name="make-safe">
<xsl:with-param name="str" select="concat($section-no, text())"/>
</xsl:call-template>
</xsl:variable>
<xsl:attribute name="target">
<xsl:value-of select="substring-after(@href,'#')"/>
</xsl:attribute>
<xsl:attribute name="text">
<xsl:value-of select="$text"/>
</xsl:attribute>
<xsl:apply-templates select="link"/>
</tocitem>
</xsl:template>

<!-- B: STRING FUNCTIONS -->
<!-- common space characters -->
<xsl:variable name="lf">
<xsl:text>
</xsl:text>
</xsl:variable>
<xsl:variable name="tab">
<xsl:text>	</xsl:text>
</xsl:variable>
<xsl:variable name="lftab">
<xsl:copy-of select="$lf"/>
<xsl:copy-of select="$tab"/>
</xsl:variable>
<!-- template to replace characters like tab, newline, etc -->
<xsl:template name="make-safe">
<xsl:param name="str"/>
<xsl:variable name="replacement" select="concat('','')"/>
<xsl:variable name="tab-safe">
<xsl:call-template name="replace-text">
<xsl:with-param name="str" select="$str"/>
<xsl:with-param name="replace" select="$tab"/>
<xsl:with-param name="replacement" select="$replacement"/>
</xsl:call-template>
</xsl:variable>
<xsl:variable name="lf-safe">
<xsl:call-template name="replace-text">
<xsl:with-param name="str" select="$tab-safe"/>
<xsl:with-param name="replace" select="$lf"/>
<xsl:with-param name="replacement" select="$replacement"/>
</xsl:call-template>
</xsl:variable>
<xsl:variable name="safe">
<xsl:call-template name="replace-text">
<xsl:with-param name="str" select="$lf-safe"/>
<xsl:with-param name="replace" select="$lftab"/>
<xsl:with-param name="replacement" select="$replacement"/>
</xsl:call-template>
</xsl:variable>
<xsl:value-of select="$safe"/>
</xsl:template>
<!-- template to replace text -->
<xsl:template name="replace-text">
<xsl:param name="str"/>
<xsl:param name="replace"/>
<xsl:param name="replacement"/>
<xsl:choose>
<xsl:when test="contains($str, $replace)">
<xsl:value-of select="concat(substring-before($str, $replace), $replacement)"/>
<xsl:call-template name="replace-text">
<xsl:with-param name="str" select="substring-after($str, $replace)"/>
<xsl:with-param name="replace" select="$replace"/>
<xsl:with-param name="replacement" select="$replacement"/>
</xsl:call-template>
</xsl:when>
<xsl:otherwise>
<xsl:value-of select="$str"/>
</xsl:otherwise>
</xsl:choose>
</xsl:template>
<!-- E: STRING FUNCTIONS -->

</xsl:stylesheet>
